[Libreoffice-commits] .: configmgr/source framework/inc framework/source sd/source vcl/unx xmloff/inc xmloff/source

Lubos Lunak llunak at kemper.freedesktop.org
Mon Jul 16 10:46:51 PDT 2012


 configmgr/source/components.cxx                  |    2 +-
 framework/inc/services/frameloaderfactory.hxx    |    2 +-
 framework/source/inc/loadenv/targethelper.hxx    |    4 ++--
 framework/source/services/substitutepathvars.cxx |    2 +-
 sd/source/filter/ppt/pptinanimations.cxx         |    4 ++--
 vcl/unx/generic/printer/cupsmgr.cxx              |    2 +-
 xmloff/inc/xmloff/xmlerror.hxx                   |    2 +-
 xmloff/source/core/xmlimp.cxx                    |    4 ++--
 xmloff/source/transform/TransformerBase.cxx      |    2 +-
 9 files changed, 12 insertions(+), 12 deletions(-)

New commits:
commit e0f7e213af28c8397bcc69b007a3c88248287a5f
Author: Luboš Luňák <l.lunak at suse.cz>
Date:   Mon Jul 16 19:37:32 2012 +0200

    the unknwon typo is surprisingly popular
    
    Change-Id: Iffe25051c8357019521196f9a27065d6108ede47

diff --git a/configmgr/source/components.cxx b/configmgr/source/components.cxx
index 404b60a..e42fb48 100644
--- a/configmgr/source/components.cxx
+++ b/configmgr/source/components.cxx
@@ -470,7 +470,7 @@ css::beans::Optional< css::uno::Any > Components::getExternalValue(
             throw css::uno::RuntimeException(
                 (rtl::OUString(
                     RTL_CONSTASCII_USTRINGPARAM(
-                        "unknwon external value descriptor ID: ")) +
+                        "unknown external value descriptor ID: ")) +
                  e.Message),
                 css::uno::Reference< css::uno::XInterface >());
         } catch (css::lang::WrappedTargetException & e) {
diff --git a/framework/inc/services/frameloaderfactory.hxx b/framework/inc/services/frameloaderfactory.hxx
index 1e7fe20..8fb3d80 100644
--- a/framework/inc/services/frameloaderfactory.hxx
+++ b/framework/inc/services/frameloaderfactory.hxx
@@ -253,7 +253,7 @@ class FrameLoaderFactory    :   public ThreadHelpBase
             @short      check if searched frame loader exist in configuration
             @descr      Normaly nobody need these method realy (use getElementNames() in combination with getByName()).
                         We guarantee correctness of these mechanism. There is no reason to check for existing elements then ...
-                        but if you have an unknwon name and has no fun to search it in returned sequence ...
+                        but if you have an unknown name and has no fun to search it in returned sequence ...
                         you can call these ...
 
             @seealso    method getByName()
diff --git a/framework/source/inc/loadenv/targethelper.hxx b/framework/source/inc/loadenv/targethelper.hxx
index 69fc9e5..7af9e7f 100644
--- a/framework/source/inc/loadenv/targethelper.hxx
+++ b/framework/source/inc/loadenv/targethelper.hxx
@@ -76,7 +76,7 @@ class TargetHelper
             @note   An empty target is similar to "_self"!
 
             @param  sCheckTarget
-                    must be the unknwon target name, which should be checked.
+                    must be the unknown target name, which should be checked.
 
             @param  eSpecialTarget
                     represent the expected target.
@@ -100,7 +100,7 @@ class TargetHelper
                     by definition inside the same frame tree (e.g. _beamer and
                     OFFICE_HELP_TASK) its not a good idea to allow anything here :-)
 
-                    Of course we can't check unknwon names, which are not special ones.
+                    Of course we can't check unknown names, which are not special ones.
                     But we decide, that it's not allowed to use "_" as first sign
                     (because we reserve this letter for our own purposes!)
                     and the value must not a well known special target.
diff --git a/framework/source/services/substitutepathvars.cxx b/framework/source/services/substitutepathvars.cxx
index 42f27f7..3e58f94 100644
--- a/framework/source/services/substitutepathvars.cxx
+++ b/framework/source/services/substitutepathvars.cxx
@@ -987,7 +987,7 @@ throw ( NoSuchElementException, RuntimeException )
         }
         else
         {
-            // variable in text but unknwon!
+            // variable in text but unknown!
             if ( bSubstRequired )
             {
                 rtl::OUString aMsg( RTL_CONSTASCII_USTRINGPARAM( "Unknown variable found!" ));
diff --git a/sd/source/filter/ppt/pptinanimations.cxx b/sd/source/filter/ppt/pptinanimations.cxx
index b519247..03e0203 100644
--- a/sd/source/filter/ppt/pptinanimations.cxx
+++ b/sd/source/filter/ppt/pptinanimations.cxx
@@ -3112,7 +3112,7 @@ sal_Int32 AnimationImporter::importTargetElementContainer( const Atom* pAtom, An
             }
             break;
             default:
-                OSL_FAIL("unknwon atom inside ppt::AnimationImporter::importTargetElementContainer()!");
+                OSL_FAIL("unknown atom inside ppt::AnimationImporter::importTargetElementContainer()!");
                 break;
             }
 
@@ -3143,7 +3143,7 @@ void AnimationImporter::importPropertySetContainer( const Atom* pAtom, PropertyS
             }
             else
             {
-                OSL_FAIL("unknwon atom inside ppt::AnimationImporter::importPropertySetContainer()!");
+                OSL_FAIL("unknown atom inside ppt::AnimationImporter::importPropertySetContainer()!");
             }
 
             pChildAtom = pAtom->findNextChildAtom( pChildAtom );
diff --git a/vcl/unx/generic/printer/cupsmgr.cxx b/vcl/unx/generic/printer/cupsmgr.cxx
index 858cf2a..367f09d 100644
--- a/vcl/unx/generic/printer/cupsmgr.cxx
+++ b/vcl/unx/generic/printer/cupsmgr.cxx
@@ -520,7 +520,7 @@ void CUPSManager::initialize()
             m_aGlobalDefaults.m_nPDFDevice = 1;
     }
     // do not send include JobPatch; CUPS will insert that itself
-    // TODO: currently unknwon which versions of CUPS insert JobPatches
+    // TODO: currently unknown which versions of CUPS insert JobPatches
     // so currently it is assumed CUPS = don't insert JobPatch files
     m_bUseJobPatch = false;
 
diff --git a/xmloff/inc/xmloff/xmlerror.hxx b/xmloff/inc/xmloff/xmlerror.hxx
index b5fbbd8..eb84e51 100644
--- a/xmloff/inc/xmloff/xmlerror.hxx
+++ b/xmloff/inc/xmloff/xmlerror.hxx
@@ -74,7 +74,7 @@
 #define XMLERROR_UNKNOWN_ATTRIBUTE ( XMLERROR_CLASS_FORMAT | XMLERROR_FLAG_WARNING | 0x0000000a )
 #define XMLERROR_UNKNOWN_ELEMENT ( XMLERROR_CLASS_FORMAT | XMLERROR_FLAG_WARNING | 0x0000000b )
 #define XMLERROR_UNKNOWN_CHARACTERS ( XMLERROR_CLASS_FORMAT | XMLERROR_FLAG_WARNING | 0x0000000c )
-#define XMLERROR_UNKNWON_ROOT (XMLERROR_CLASS_FORMAT | 0x0000000d )
+#define XMLERROR_UNKNOWN_ROOT (XMLERROR_CLASS_FORMAT | 0x0000000d )
 
 // API errors:
 #define XMLERROR_STYLE_PROP_VALUE   ( XMLERROR_CLASS_API    | 0x00000001 )
diff --git a/xmloff/source/transform/TransformerBase.cxx b/xmloff/source/transform/TransformerBase.cxx
index e277f4e..3920d82 100644
--- a/xmloff/source/transform/TransformerBase.cxx
+++ b/xmloff/source/transform/TransformerBase.cxx
@@ -266,7 +266,7 @@ void SAL_CALL XMLTransformerBase::startElement( const OUString& rName,
                                  : rAttrName.copy( 6 ) );
             // Add namespace, but only if it is known.
             sal_uInt16 nKey = m_pNamespaceMap->AddIfKnown( aPrefix, rAttrValue );
-            // If namespace is unknwon, try to match a name with similar
+            // If namespace is unknown, try to match a name with similar
             // TC Id an version
             if( XML_NAMESPACE_UNKNOWN == nKey  )
             {


More information about the Libreoffice-commits mailing list
diff --git a/xmloff/source/core/xmlimp.cxx b/xmloff/source/core/xmlimp.cxx
index d2567a7..30e130b 100644
--- a/xmloff/source/core/xmlimp.cxx
+++ b/xmloff/source/core/xmlimp.cxx
@@ -612,7 +612,7 @@ void SAL_CALL SvXMLImport::startElement( const OUString& rName,
                                  : rAttrName.copy( 6 ) );
             // Add namespace, but only if it is known.
             sal_uInt16 nKey = mpNamespaceMap->AddIfKnown( aPrefix, rAttrValue );
             // If namespace is unknwon, try to match a name with similar
             // TC Id an version
             if( XML_NAMESPACE_UNKNOWN == nKey  )
             {
@@ -664,7 +664,7 @@ void SAL_CALL SvXMLImport::startElement( const OUString& rName,
             Sequence < OUString > aParams(1);
             aParams.getArray()[0] = rName;
 
-            SetError( XMLERROR_FLAG_SEVERE|XMLERROR_UNKNWON_ROOT,
+            SetError( XMLERROR_FLAG_SEVERE|XMLERROR_UNKNOWN_ROOT,
                       aParams, aMsg, xDummyLocator );
         }
     }
@@ -612,7 +612,7 @@ void SAL_CALL SvXMLImport::startElement( const OUString& rName,
             // Add namespace, but only if it is known.
             sal_uInt16 nKey = mpNamespaceMap->AddIfKnown( aPrefix, rAttrValue );
-            // If namespace is unknwon, try to match a name with similar
+            // If namespace is unknown, try to match a name with similar
             // TC Id an version
             if( XML_NAMESPACE_UNKNOWN == nKey  )